@@ -6,20 +6,20 @@ package av1
 
 import (
 	"github.com/wader/fq/format"
-	"github.com/wader/fq/format/registry"
 	"github.com/wader/fq/pkg/decode"
+	"github.com/wader/fq/pkg/interp"
 	"github.com/wader/fq/pkg/scalar"
 )
 
 func init() {
-	registry.MustRegister(decode.Format{
+	interp.RegisterFormat(decode.Format{
 		Name:        format.AV1_CCR,
 		Description: "AV1 Codec Configuration Record",
 		DecodeFn:    ccrDecode,
 	})
 }
 
-func ccrDecode(d *decode.D, in interface{}) interface{} {
+func ccrDecode(d *decode.D, _ any) any {
 	d.FieldU1("marker")
 	d.FieldU7("version")
 	d.FieldU3("seq_profile")
@@ -34,7 +34,7 @@ func ccrDecode(d *decode.D, in interface{}) interface{} {
 	d.FieldU3("reserved = 0")
 	initalPreDelay := d.FieldBool("initial_presentation_delay_present")
 	if initalPreDelay {
-		d.FieldU4("initial_presentation_delay", scalar.UAdd(1))
+		d.FieldU4("initial_presentation_delay", scalar.ActualUAdd(1))
 	} else {
 		d.FieldU4("reserved")
 	}
