@@ -7,7 +7,7 @@ import (
 
 func decodeIntFn(sms ...scalar.Mapper) (DecodeFn, error) {
 	// Int and long values are written using variable-length zig-zag coding.
-	return func(name string, d *decode.D) interface{} {
+	return func(name string, d *decode.D) any {
 		return d.FieldSFn(name, VarZigZag, sms...)
 	}, nil
 }
