@@ -17,11 +17,8 @@ func init() {
 	interp.RegisterFormat(decode.Format{
 		Name:        format.DNS,
 		Description: "DNS packet",
-		Groups: []string{
-			format.TCP_STREAM,
-			format.UDP_PAYLOAD,
-		},
-		DecodeFn: dnsUDPDecode,
+		Groups:      []string{format.UDP_PAYLOAD},
+		DecodeFn:    dnsUDPDecode,
 	})
 }
 
@@ -141,8 +138,6 @@ func fieldDecodeLabel(d *decode.D, pointerOffset int64, name string) {
 	d.FieldStruct(name, func(d *decode.D) {
 		var ls []string
 		d.FieldArray("labels", func(d *decode.D) {
-			d.RangeSorted = false
-
 			seenTermintor := false
 			for !seenTermintor {
 				d.FieldStruct("label", func(d *decode.D) {
@@ -178,8 +173,6 @@ func fieldDecodeLabel(d *decode.D, pointerOffset int64, name string) {
 
 func dnsDecodeRR(d *decode.D, pointerOffset int64, resp bool, count uint64, name string, structName string) {
 	d.FieldArray(name, func(d *decode.D) {
-		d.RangeSorted = false
-
 		for i := uint64(0); i < count; i++ {
 			d.FieldStruct(structName, func(d *decode.D) {
 				fieldDecodeLabel(d, pointerOffset, "name")
@@ -229,10 +222,10 @@ func dnsDecodeRR(d *decode.D, pointerOffset int64, resp bool, count uint64, name
 	})
 }
 
-func dnsDecode(d *decode.D, isTCP bool) any {
+func dnsDecode(d *decode.D, hasLengthHeader bool) any {
 	pointerOffset := int64(0)
 	d.FieldStruct("header", func(d *decode.D) {
-		if isTCP {
+		if hasLengthHeader {
 			pointerOffset = 16
 			d.FieldU16("length")
 		}
