@@ -45,6 +45,7 @@ const (
 	BITCOIN_BLOCK       = "bitcoin_block"
 	BITCOIN_SCRIPT      = "bitcoin_script"
 	BITCOIN_TRANSACTION = "bitcoin_transaction"
+	BPLIST              = "bplist"
 	BSD_LOOPBACK_FRAME  = "bsd_loopback_frame"
 	BSON                = "bson"
 	BZIP2               = "bzip2"
@@ -86,6 +87,7 @@ const (
 	JSONL               = "jsonl"
 	MACHO               = "macho"
 	MACHO_FAT           = "macho_fat"
+	MARKDOWN            = "markdown"
 	MATROSKA            = "matroska"
 	MP3                 = "mp3"
 	MP3_FRAME           = "mp3_frame"
@@ -310,3 +312,7 @@ type CSVLIn struct {
 	Comma   string `doc:"Separator character"`
 	Comment string `doc:"Comment line character"`
 }
+
+type BitCoinBlockIn struct {
+	HasHeader bool `doc:"Has blkdat header"`
+}
