@@ -9,13 +9,13 @@ import (
 	"strings"
 
 	"github.com/wader/fq/format"
-	"github.com/wader/fq/format/registry"
 	"github.com/wader/fq/pkg/decode"
+	"github.com/wader/fq/pkg/interp"
 	"github.com/wader/fq/pkg/scalar"
 )
 
 func init() {
-	registry.MustRegister(decode.Format{
+	interp.RegisterFormat(decode.Format{
 		Name:        format.MPEG_SPU,
 		Description: "Sub Picture Unit (DVD subtitle)",
 		DecodeFn:    spuDecode,
@@ -70,7 +70,8 @@ func rleValue(d *decode.D) (uint64, uint64, int) {
 	}
 }
 
-func decodeLines(d *decode.D, lines int, width int) []string { //nolint:unparam
+//nolint:unparam
+func decodeLines(d *decode.D, lines int, width int) []string {
 	var ls []string
 
 	for i := 0; i < lines; i++ {
@@ -99,7 +100,7 @@ func decodeLines(d *decode.D, lines int, width int) []string { //nolint:unparam
 	return ls
 }
 
-func spuDecode(d *decode.D, in interface{}) interface{} {
+func spuDecode(d *decode.D, _ any) any {
 	d.FieldU16("size")
 	dcsqtOffset := d.FieldU16("dcsqt_offset")
 
