@@ -9,9 +9,9 @@ import (
 	"hash/crc32"
 
 	"github.com/wader/fq/format"
-	"github.com/wader/fq/format/registry"
 	"github.com/wader/fq/pkg/bitio"
 	"github.com/wader/fq/pkg/decode"
+	"github.com/wader/fq/pkg/interp"
 	"github.com/wader/fq/pkg/scalar"
 )
 
@@ -19,7 +19,7 @@ var iccProfileFormat decode.Group
 var exifFormat decode.Group
 
 func init() {
-	registry.MustRegister(decode.Format{
+	interp.RegisterFormat(decode.Format{
 		Name:        format.PNG,
 		Description: "Portable Network Graphics file",
 		Groups:      []string{format.PROBE, format.IMAGE},
@@ -77,7 +77,7 @@ var colorTypeMap = scalar.UToSymStr{
 	colorTypeRGBA:               "rgba",
 }
 
-func pngDecode(d *decode.D, in interface{}) interface{} {
+func pngDecode(d *decode.D, _ any) any {
 	iEndFound := false
 	var colorType uint64
 
@@ -127,7 +127,7 @@ func pngDecode(d *decode.D, in interface{}) interface{} {
 
 				switch compressionMethod {
 				case compressionDeflate:
-					d.FieldFormatReaderLen("uncompressed", dataLen, zlib.NewReader, decode.FormatFn(func(d *decode.D, in interface{}) interface{} {
+					d.FieldFormatReaderLen("uncompressed", dataLen, zlib.NewReader, decode.FormatFn(func(d *decode.D, _ any) any {
 						d.FieldUTF8("text", int(d.BitsLeft()/8))
 						return nil
 					}))
@@ -228,8 +228,8 @@ func pngDecode(d *decode.D, in interface{}) interface{} {
 		})
 
 		chunkCRC := crc32.NewIEEE()
-		d.MustCopy(chunkCRC, bitio.NewIOReader(d.BitBufRange(crcStartPos, d.Pos()-crcStartPos)))
-		d.FieldU32("crc", d.ValidateUBytes(chunkCRC.Sum(nil)), scalar.Hex)
+		d.Copy(chunkCRC, bitio.NewIOReader(d.BitBufRange(crcStartPos, d.Pos()-crcStartPos)))
+		d.FieldU32("crc", d.ValidateUBytes(chunkCRC.Sum(nil)), scalar.ActualHex)
 	})
 
 	return nil
