@@ -12,7 +12,7 @@ import (
 	"github.com/wader/fq/pkg/scalar"
 )
 
-//go:embed protobuf.jq
+//go:embed protobuf.md
 var protobufFS embed.FS
 
 func init() {
@@ -20,7 +20,6 @@ func init() {
 		Name:        format.PROTOBUF,
 		Description: "Protobuf",
 		DecodeFn:    protobufDecode,
-		Functions:   []string{"_help"},
 	})
 	interp.RegisterFS(protobufFS)
 }
@@ -70,7 +69,7 @@ func protobufDecodeField(d *decode.D, pbm *format.ProtoBufMessage) {
 
 				switch pbf.Type {
 				case format.ProtoBufTypeInt32, format.ProtoBufTypeInt64:
-					v := mathex.ZigZag(value)
+					v := mathex.ZigZag[uint64, int64](value)
 					d.FieldValueS("value", v)
 					if len(pbf.Enums) > 0 {
 						d.FieldValueStr("enum", pbf.Enums[uint64(v)])
