@@ -13,6 +13,7 @@ import (
 )
 
 //go:embed html.jq
+//go:embed html.md
 var htmlFS embed.FS
 
 func init() {
@@ -175,7 +176,20 @@ func fromHTMLToArray(n *html.Node) any {
 		return elm
 	}
 
-	return f(n.FirstChild)
+	// find first element node, skip doctype etc, should be a "html" element
+	for c := n.FirstChild; c != nil; c = c.NextSibling {
+		if c.Type == html.ElementNode {
+			n = c
+			break
+		}
+	}
+
+	// should not happen
+	if n == nil {
+		panic("unreachable")
+	}
+
+	return f(n)
 }
 
 func decodeHTML(d *decode.D, in any) any {
