@@ -2,17 +2,17 @@ package decode
 
 import (
 	"errors"
-	"sort"
 
 	"github.com/wader/fq/pkg/bitio"
 	"github.com/wader/fq/pkg/ranges"
 	"github.com/wader/fq/pkg/scalar"
+	"golang.org/x/exp/slices"
 )
 
 type Compound struct {
 	IsArray     bool
-	RangeSorted bool
 	Children    []*Value
+	ByName      map[string]*Value
 	Description string
 }
 
@@ -197,12 +197,9 @@ func (v *Value) postProcess() {
 				}
 			}
 
-			// TODO: really sort array? if sort it needs to be stable to keep the order
-			// of value with same range start, think null values etc
-			if vv.RangeSorted {
-				sort.SliceStable(vv.Children, func(i, j int) bool {
-					return (vv.Children)[i].Range.Start < (vv.Children)[j].Range.Start
-				})
+			// sort struct fields and make sure to keep order if range is the same
+			if !vv.IsArray {
+				slices.SortStableFunc(vv.Children, func(a, b *Value) bool { return a.Range.Start < b.Range.Start })
 			}
 
 			v.Index = -1
